@@ -1,13 +1,39 @@
+#!/usr/bin/env perl
+#
+# Tutorial.pm
+#
+# Copyright (C) 2005 David J. Goehrig <dgoehrig@cpan.org>
+#
+# ------------------------------------------------------------------------------
+#
+# This library is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or (at your option) any later version.
+# 
+# This library is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+# 
+# You should have received a copy of the GNU Lesser General Public
+# License along with this library; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+#
+# ------------------------------------------------------------------------------
+#
+# Please feel free to send questions, suggestions or improvements to:
+#
+#	David J. Goehrig
+#	dgoehrig@cpan.org
+#
+
 package SDL::Tutorial;
 
-use Pod::ToDemo;
-
-return 1 if defined caller();
-
-Pod::ToDemo::write_demo( shift, "#!$^X\n" . <<'END_HERE' );
 use strict;
 use warnings;
 
+use SDL;
 use SDL::App;
 
 # change these values as necessary
@@ -23,7 +49,8 @@ my $app = SDL::App->new(
 
 # your code here; remove the next line
 sleep 2;
-END_HERE
+
+1;
 
 __END__
 
@@ -37,7 +64,7 @@ SDL::Tutorial - introduction to Perl SDL
 	$ perldoc SDL::Tutorial
 
 	# to create a bare-bones SDL app based on this tutorial
-	$ perl -MSDL::Tutorial basic_app.pl
+	$ perl -MSDL::Tutorial -e 1
 
 =head1 SDL BASICS
 
